<?php

namespace BeycanPress\Licensor;

use BeycanPress\Licensor\PluginHero\Plugin;

class Loader extends Plugin
{
    public function __construct($pluginFile)
    {
        parent::__construct([
            'pluginFile' => $pluginFile,
            'pluginKey' => 'licensor',
            'textDomain' => 'licensor',
            'settingKey' => 'licensorSettings',
            'pluginVersion' => '1.0.1'
        ]);

        $this->createEndpointLink = function($endpoint) {
            return get_permalink(get_option('woocommerce_myaccount_page_id')) . $endpoint;
        };

        if ($this->setting('license')) {
            if (!is_admin()) {
                new Api();
            } 
            add_action('plugins_loaded', function() {
                if (function_exists('WC')) {
                    new WooCommerce\LicenseProcess();
                }
            });
        } else {
            $this->adminNotice(esc_html__('In order to use the "Licensor" Plugin, please enter your license (purchase) code in the license field in the settings section.', 'licensor'), 'error');
        }
    }

    public function adminProcess()
    {
        (new Models\License())->updateTable();
        
        new Pages\LicenseList();
        new Pages\CreateLicense();
        new Pages\EditLicense();
        new Pages\CheckFromEnvato();
        
        add_action('init', function(){
            new Settings;
        }, 9);
    }

    public function frontendProcess() 
    {
        add_action('init', function() {
            header("Access-Control-Allow-Origin: *");
        });
    }

    public static function activation()
    {
        (new Models\License())->createTable();
    }

    public static function uninstall()
    {
        $settings = get_option(self::$instance->settingKey);
        if (isset($settings['dds']) && $settings['dds']) {
            delete_option(self::$instance->settingKey);
            (new Models\License())->drop();
        }
    }
}
