<?php 

namespace BeycanPress\Licensor\Pages;

use Beycan\WPTable\Table;
use BeycanPress\Licensor\Models\License;
use BeycanPress\Licensor\PluginHero\Page;

/**
 * Edit license page
 */
class EditLicense extends Page
{   
    private $model;

    /**
     * Class construct
     * @return void
     */
    public function __construct()
    {
        $this->model = new License();
        
        if (isset($_POST['update'])) {
            $this->updateLicense();
        }

        parent::__construct([
            'pageName' => esc_html__('Edit license', 'licensor'),
            'hidden' => true
        ]);
    }

    /**
     * @return void
     */
    public function page()
    {
        $licenseId = isset($_GET['id']) ? absint($_GET['id']) : 0;
        $license = (array) $this->model->findOneBy(['id' => $licenseId]);

        if (!$license) {
            return $this->notice(esc_html__('License not found', 'licensor'), 'error');
        }

        $this->viewEcho('pages/license/edit', compact('license'));
    }

    /**
     * @return void
     */
    private function updateLicense() 
    {
        $licenseData = $_POST;

        $licenseData = array_map('sanitize_text_field', $licenseData);
        $licenseData['email'] = sanitize_email($licenseData['email']);
        $licenseData['support'] = floatval($licenseData['support']);
        $licenseData['status'] = absint($licenseData['status']);
        $licenseId = absint($licenseData['id']);

        unset($licenseData['update'], $licenseData['id']);
        
        $this->model->update($licenseData, ['id' => $licenseId]);

        $this->adminRedirect($this->pages->LicenseList->getUrl() . '&updated=1');
    }

}