<?php 

namespace BeycanPress\Licensor\Pages;

use Beycan\WPTable\Table;
use BeycanPress\Licensor\Models\License;
use BeycanPress\Licensor\PluginHero\Page;

/**
 * License list page
 */
class LicenseList extends Page
{   
    /**
     * Class construct
     * @return void
     */
    public function __construct()
    {
        parent::__construct([
            'pageName' => esc_html__('Licensor', 'licensor'),
            'subMenuPageName' => esc_html__('License list', 'licensor'),
            'subMenu' => true,
            'icon' => 'dashicons-admin-network'
        ]);
    }

    /**
     * @return void
     */
    public function page()
    {
        $license = new License();

        if (isset($_GET['added'])){
            $this->notice(esc_html__('License have been created successfully.', 'licensor'), 'success', true);
        }

        if (isset($_GET['updated'])){
            $this->notice(esc_html__('License have been updated successfully.', 'licensor'), 'success', true);
        }
        
        if (isset($_GET['id']) && $license->delete(['id' => absint($_GET['id'])])) {
            $this->notice(esc_html__('Successfully deleted!', 'licensor'), 'success', true);
        }
        
        $table = (new Table($license))->setColumns([
            'productId'       => esc_html__('Product id', 'licensor'),
            'product'         => esc_html__('Product', 'licensor'),
            'licenseCode'     => esc_html__('License code', 'licensor'),
            'licenseType'     => esc_html__('License type', 'licensor'),
            'domain'          => esc_html__('Domain', 'licensor'),
            'earning'         => esc_html__('Earning', 'licensor'),
            'buyer'           => esc_html__('Buyer', 'licensor'),
            'placeOfPurchase' => esc_html__('Place of purchase', 'licensor'),
            'status'          => esc_html__('Status', 'licensor'),
            'soldAt'          => esc_html__('Sold at', 'licensor'),
            'expireTime'      => esc_html__('Expire time', 'licensor'),
            'createdAt'       => esc_html__('Created at', 'licensor'),
            'edit'            => esc_html__('Edit', 'licensor'),
            'delete'          => esc_html__('Delete', 'licensor')
        ])
        ->setOrderQuery(['createdAt', 'desc'])
        ->setOptions([
            'search' => [
                'id' => 'search-box',
                'title' => esc_html__('Search...', 'licensor')
            ]
        ])
        ->addHooks([
            'licenseType' => function($license) {
                $licenseTypeEnums = $this->setting('licenseTypeEnums');
                $licenseTypeEnumIndex = array_search($license->licenseType, array_column($licenseTypeEnums, 'number'));
                return $licenseTypeEnums[$licenseTypeEnumIndex]['licenseType'] ?? esc_html__('Undefined', 'licensor');
            },
            'buyer' => function($license) {
                if ($license->placeOfPurchase == 1) {
                    $url = 'https://codecanyon.net/user/'.$license->buyer;
                } else {
                    if ($user = get_user_by('login', $license->buyer)) {
                        $url = get_author_posts_url($user->ID);
                    }
                }

                if (isset($url)) {
                    return '<a href="'.esc_url($url).'" target="_blank">'.esc_html($license->buyer).'</a>';
                } else {
                    return esc_html($license->buyer);
                }
            },
            'placeOfPurchase' => function($license) {
                return $license->placeOfPurchase == 1 ? esc_html__('CodeCanyon', 'licensor') : esc_html__('My store', 'licensor');
            },
            'status' => function($license) {
                return $license->status == 1 ? esc_html__('Active', 'licensor') : esc_html__('Passive', 'licensor');
            },
            'expireTime' => function($license) {
                if ($license->expireTime) : 
                    return esc_html(date_i18n(get_option('date_format'), strtotime($license->expireTime))); 
                else:
                    return esc_html__('Never', 'licensor'); 
                endif;
            },
            'edit' => function($license) {
                return '<a class="button" href="'. $this->pages->EditLicense->getUrl() . '&id=' . $license->id.'">'.esc_html__('Edit', 'licensor').'</a>';
            },
            'delete' => function($license) {
                return '<a class="button" href="'.$this->getCurrentUrl() . '&id=' . $license->id.'">'.esc_html__('Delete', 'licensor').'</a>';
            }
        ])
        ->addHeaderElements(function() {
            return $this->view('pages/license/form');
        })
        ->setSortableColumns([
            'createdAt', 'expireTime'
        ])
        ->createDataList(function(object $model, array $orderQuery, int $limit, int $offset) {
            if (isset($_GET['status']) && !empty($_GET['status'])) {
                $s = sanitize_text_field($_GET['status']);
                if (isset($dataList)) {
                    $dataList = array_filter($dataList, function($obj) use ($s) {
                        return $obj->status == $s;
                    });
                    $dataListCount = count($dataList);
                } else {
                    $dataList = $model->findBy([
                        'status' => $s,
                    ], $orderQuery, $limit, $offset);
                    $dataListCount = $model->getCount([
                        'status' => $s,
                    ]);
                }

                return [$dataList, $dataListCount];
            } 

            return null;
        });

        $this->viewEcho('pages/license/list', [
            'table' => $table
        ]);
    }
}