<?php

namespace BeycanPress\Licensor\WooCommerce;

use BeycanPress\Licensor\PluginHero\Helpers;

class MyAccount 
{
    use Helpers;

    /**
     * @var array
     */
    private $queryVars = [];

    public function __construct()
    {
        $this->queryVars = [
            'my-licenses' => 'my-licenses',
            'view-license' => 'view-license',
        ];

        add_action('wp_head', [$this, 'wpHeadStyle']);

        add_filter('woocommerce_account_menu_items', [$this, 'woocommerceAccountMenuItems'], 10, 1);
        add_filter('woocommerce_account_menu_item_classes', [$this, 'maybeAddActiveClass'], 10, 2);
        
        add_filter('woocommerce_endpoint_my-licenses_title', [$this, 'changeMyAccountEndpointTitle'], 10, 2);
        add_filter('woocommerce_endpoint_view-license_title', [$this, 'changeMyAccountEndpointTitle'], 10, 2);

        add_filter('woocommerce_get_endpoint_url', [$this, 'woocommerceGetEndpointUrl'], 10, 2);
        add_filter('woocommerce_get_query_vars', [$this, 'addQueryVars']);
        add_action('woocommerce_account_my-licenses_endpoint', [$this, 'woocommerceAccountMyLicensesEndpoint']);
        add_action('woocommerce_account_view-license_endpoint', [$this, 'woocommerceAccountViewLicenseEndpoint']);

        if (get_option('licensorFlushRewrite') != 1) {
            flush_rewrite_rules(false);
            update_option('licensorFlushRewrite', 1);
        }
    }

    /**
	 * @param array $classes 
	 * @param string $endpoint 
	 * @return array
	 */
	public function maybeAddActiveClass(array $classes, string $endpoint) : array 
    {
        global $wp;
    
        $isViewLicensePage = is_page(wc_get_page_id('myaccount')) && isset($wp->query_vars['view-license']);

		if (!isset( $classes['is-active']) && 'my-licenses' === $endpoint && $isViewLicensePage) {
			$classes[] = 'is-active';
		}

		return $classes;
	}

    /**
     * @param mixed $currentPage
     * @return void
     */
    public function woocommerceAccountMyLicensesEndpoint($currentPage = 1) : void
    {
        $licenses = LicenseProcess::$licenseModel->findBy(
            ['buyer' => LicenseProcess::$currentUser->user_login],
            ['id', 'DESC']
        );
        $currentPage   = empty($currentPage) ? 1 : absint($currentPage);
        $postsPerPage  = get_option('posts_per_page');
        $maxNumPages   = ceil(count($licenses) / $postsPerPage);
        $subscriptions = array_slice($licenses, ($currentPage - 1) * $postsPerPage, $postsPerPage);

        $this->viewEcho('my-licenses', [
            'licenses' => $subscriptions,
            'maxNumPages' => $maxNumPages,
            'currentPage' => $currentPage,
            'paginate'      => true,
        ]);
    }

    /**
     * @param int $licenseId
     * @return void
     */
    public function woocommerceAccountViewLicenseEndpoint(int $licenseId) : void
    {
        $license = LicenseProcess::$licenseModel->findOneBy(['id' => (int) $licenseId]);
        $this->viewEcho('single-license', ['license' => $license]);
    }

    /**
     * @param array $menuLinks
     * @return array
     */
    public function woocommerceAccountMenuItems(array $menuLinks) : array
    {
        unset($menuLinks['customer-logout']);
        $menuLinks['my-licenses'] = esc_html__('My licenses', 'licensor');
        $menuLinks['customer-logout'] = esc_html__('Logout', 'woocommerce');
        
        return $menuLinks;
    }

    /** 
	 * @param string $title
	 * @param string $endpoint
	 * @return string
	 *
	 * @since 3.0.10
	 */
	public function changeMyAccountEndpointTitle(string $title, string $endpoint) : string 
    {
		global $wp;

		switch ($endpoint) {
			case 'view-license':
                $license = LicenseProcess::$licenseModel->findOneBy(['id' => $wp->query_vars['view-license']]);
                $title = sprintf(esc_html__('License #%s', 'licensor'), $license->id);
				break;
			case 'my-licenses':
				$title = esc_html__('My licenses', 'licensor');
				break;
		}

		return $title;
	}

    /**
     * @param string $url
     * @param string $endpoint
     * @return string
     */
    public function woocommerceGetEndpointUrl(string $url, string $endpoint) : string
    {
        if ('my-licenses' === $endpoint) {
            $url = $this->createEndpointLink($endpoint);
        }

        return $url;
    }

    /**
     * @param array $queryVars
     * @return array
     */
    public function addQueryVars(array $queryVars) : array
    {
        return array_merge($queryVars, $this->queryVars);
    }

    /**
     * @return void
     */
    public function wpHeadStyle() : void
    {
        $this->viewEcho('wp-head-style');
    }
}
